/*
DL2 Monitor: ./lib/dl2mon.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (dl2mon): Application and Library Interface
 *
 * -Packet Output Format: <header>{<tstamp><length><packet>}
 *  <header> identifies socket-type, protocol, and interface.
 *  <tstamp> 32-bit-value, timestamp of <packet> in network byte order. 
 *  <length> 16-bit-value, length of <packet> in network byte order.
 *  <packet> the data received from the packet socket.
 *  
 * -Monitor Functions:
 *  dl2_open, dl2_receive, dl2_close;
 *
 * -Constants from lib/protnos.h (DL2_*):
 *  ST_* type of packet sockets corresponding to SOCK_*;
 *  PT_* type of L2-protocols corresponding to ETH_P_* (see if_ether.h);
 *  PD_* type of L2-dummies corresponding to ETH_P_* (see if_ether.h);
 *
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History
 * 20020408  protocol numbers exported to lib/protnos.h
 * 20020408  dl2_open: interface introduced.
 * 20020330  created from scratch
 * $Id: dl2mon.h,v 1.4 2002/04/09 06:32:53 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __DL2MON_H__
# define __DL2MON_H__
# include "lib/csyntax.h"
# include "lib/protnos.h"

extern int dl2_open(int,int,const char*);
extern int dl2_receive(int,int);
extern int dl2_close(int);

# endif /*__DL2MON_H__*/
