/*
DL2 Monitor: ./lib/pappp.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (pappp): Protocol Analysis (PPP frame)
 *
 * Definitions to the PPP Framing and some of its applications:
 * PPP (RFC1661), ...
 *
 * Special Notes:
 * The distinction between IPv4 and IPv6 has been noted. However, the default
 * IP is IPv4, according to RFC1661 and Linux Network implementations.
 *   
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History
 * 20020405  distinction between IPv4 and IPv6, for some reasons.
 * 20020330  created from scratch
 * $Id: pappp.h,v 1.3 2002/04/09 06:39:18 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __PAPPP_H__
# define __PAPPP_H__

// Protocol Field Indications:
# define PAPPP_T_lcp	0xc021		/*Link Control Protocol*/
# define PAPPP_T_LCP	PAPPP_T_lcp
# define PAPPP_T_pap	0xc023		/*Password Authentication Protocol*/
# define PAPPP_T_PAP	PAPPP_T_pap
# define PAPPP_T_lqr	0xc025		/*Link Quality Report*/
# define PAPPP_T_LQR	PAPPP_T_lqr
# define PAPPP_T_chap	0xc223		/*Challenge Handshake Authentication*/
# define PAPPP_T_CHAP	PAPPP_T_chap
# define PAPPP_T_ipcp	0x8021		/*IP Control Protocol*/
# define PAPPP_T_IPCP	PAPPP_T_ipcp
# define PAPPP_T_ipv4	0x0021		/*Internet Protocol, version 4*/
# define PAPPP_T_IPv4	PAPPP_T_ipv4
# define PAPPP_T_ipv6   0x0057          /*Internet Protocol, version 6*/
# define PAPPP_T_IPv6   PAPPP_T_ipv6
# define PAPPP_T_ctcp	0x002d		/*Compressed TCP*/
# define PAPPP_T_CTCP	PAPPP_T_ctcp
# define PAPPP_T_utcp	0x002f		/*Uncompressed TCP*/
# define PAPPP_T_UTCP	PAPPP_T_utcp

# define PAPPP_T_ip     PAPPP_T_ipv4	/*supported IP*/
# define PAPPP_T_IP     PAPPP_T_ipv4

// others: tbd

# endif /*__PAPPP_H__*/
