/*
DL2 Monitor: ./lib/protnos.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (protnos): Application and Library Interface
 *
 * The protocol number definitions refer to the Ethernet Framing and have been
 * derived from the linux/if_ether.h include file. The semantic is carried by
 * name, the values have been renumbered for some reasons. Note, however, that
 * not all of the protocols are supported by the DL2 Analyzer. There are also 
 * definitions for the socket-type argument of the Linux packet socket.
 *
 * -Constants (DL2_*):
 *  ST_* type of packet sockets corresponding to SOCK_*;
 *  PT_* type of L2-protocols corresponding to ETH_P_* (see if_ether.h);
 *  PD_* type of L2-dummies corresponding to ETH_P_* (see if_ether.h);
 *
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History
 * 20020408  created from scratch
 * $Id: protnos.h,v 1.3 2002/04/09 07:55:25 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __PROTNOS_H__
# define __PROTNOS_H__

# define DL2_ST_raw    1
# define DL2_ST_RAW    DL2_ST_raw
# define DL2_ST_dgram  2
# define DL2_ST_DGRAM  DL2_ST_dgram

# define DL2_PT_LOOP      0     /* Ethernet Loopback packet     */
# define DL2_PT_ECHO      1     /* Ethernet Echo packet         */
# define DL2_PT_ip        2     /* Internet Protocol packet     */
# define DL2_PT_IP        DL2_PT_ip
# define DL2_PT_X25       3     /* CCITT X.25                   */
# define DL2_PT_ARP       4     /* Address Resolution packet    */
# define DL2_PT_BPQ       5     /* G8BPQ AX.25 Ethernet Packet  */
# define DL2_PT_RARP      6     /* Reverse Addr Res packet      */
# define DL2_PT_IPX       7     /* IPX over DIX                 */
# define DL2_PT_IPV6      8     /* IPv6 over bluebook           */
# define DL2_PT_PPP_disc  9     /* PPPoE discovery messages     */
# define DL2_PT_PPP_DISC  DL2_PT_PPP_disc
# define DL2_PT_PPP_ses   10    /* PPPoE session messages       */
# define DL2_PT_PPP_SES   DL2_PT_PPP_ses
# define DL2_PT_ATMMPOA   11    /* MultiProtocol Over ATM       */
# define DL2_PT_ATMFATE   12    /* Frame-based ATM Transport    */

# define DL2_PD_802_3    0x100    /* Dummy type for 802.3 frames  */
# define DL2_PD_AX25     0x101    /* Dummy protocol id for AX.25  */
# define DL2_PD_all      0x102    /* Every packet (be careful!!!) */
# define DL2_PD_ALL      DL2_PD_all
# define DL2_PD_802_2    0x103    /* 802.2 frames                 */
# define DL2_PD_TR_802_2 0x104    /* 802.2 frames                 */
# define DL2_PD_CONTROL  0x105    /* Card specific control frames */
# define DL2_PD_IRDA     0x106    /* Linux-IrDA                   */

# endif /*__PROTNOS_H__*/
